@@ -705,7 +705,8 @@ int cmor_load_table(char szTable[CMOR_MAX_STRING], int *table_id)
         strcpy(cmor_tables[cmor_ntables].path, szTable);
         cmor_set_cur_dataset_attribute_internal(CV_INPUTFILENAME,
                                                 szControlFilenameJSON, 1);
-        rc = cmor_load_table_internal(szAxisEntryFilenameJSON, table_id);
+        rc = cmor_load_table_internal(szAxisEntryFilenameJSON, table_id,
+                                      CMOR_TABLE_AXIS);
         if (rc != TABLE_SUCCESS) {
             cmor_handle_error_variadic(
                 "Can't open/read JSON table %s", 
@@ -713,15 +714,8 @@ int cmor_load_table(char szTable[CMOR_MAX_STRING], int *table_id)
                 szAxisEntryFilenameJSON);
             return (1);
         }
-        rc = cmor_load_table_internal(szTable, table_id);
-        if (rc != TABLE_SUCCESS) {
-            cmor_handle_error_variadic(
-                "Can't open/read JSON table %s",
-                CMOR_CRITICAL,
-                szTable);
-            return (1);
-        }
-        rc = cmor_load_table_internal(szFormulaVarFilenameJSON, table_id);
+        rc = cmor_load_table_internal(szFormulaVarFilenameJSON, table_id,
+                                      CMOR_TABLE_FORMULA);
         if (rc != TABLE_SUCCESS) {
             cmor_handle_error_variadic(
                 "Can't open/read JSON table %s",
@@ -729,7 +723,8 @@ int cmor_load_table(char szTable[CMOR_MAX_STRING], int *table_id)
                 szFormulaVarFilenameJSON);
             return (1);
         }
-        rc = cmor_load_table_internal(szControlFilenameJSON, table_id);
+        rc = cmor_load_table_internal(szControlFilenameJSON, table_id,
+                                      CMOR_TABLE_CV);
         if (rc != TABLE_SUCCESS) {
             cmor_handle_error_variadic(
                 "Can't open/read JSON table %s",
@@ -737,6 +732,14 @@ int cmor_load_table(char szTable[CMOR_MAX_STRING], int *table_id)
                 szControlFilenameJSON);
             return (1);
         }
+        rc = cmor_load_table_internal(szTable, table_id, CMOR_TABLE_VARIABLE);
+        if (rc != TABLE_SUCCESS) {
+            cmor_handle_error_variadic(
+                "Can't open/read JSON table %s",
+                CMOR_CRITICAL,
+                szTable);
+            return (1);
+        }
 
     } else if (rc == TABLE_FOUND) {
         rc = TABLE_SUCCESS;
@@ -771,11 +774,13 @@ int cmor_search_table(char szTable[CMOR_MAX_STRING], int *table_id)
 /************************************************************************/
 /*                   cmor_load_table_internal()                         */
 /************************************************************************/
-int cmor_load_table_internal(char szTable[CMOR_MAX_STRING], int *table_id)
+int cmor_load_table_internal(char szTable[CMOR_MAX_STRING], int *table_id,
+                             enum cmor_table_type table_type)
 {
     FILE *table_file;
     char word[CMOR_MAX_STRING];
     int n;
+    int cv_found;
     int done = 0;
     extern int CMOR_TABLE, cmor_ntables;
     extern char cmor_input_path[CMOR_MAX_STRING];
@@ -909,33 +914,38 @@ int cmor_load_table_internal(char szTable[CMOR_MAX_STRING], int *table_id)
 /* -------------------------------------------------------------------- */
 /*     Process table header first as it will be used for default        */
 /*     values for the variable definitions.                             */
+/*     We only care about the variable table's header.                  */
+/*     Ignore the headers in other tables.                              */
 /* -------------------------------------------------------------------- */
-    json_object_object_foreach(json_obj, header_key, header_value) {
-        if (header_key[0] == '#') {
-            continue;
-        }
-        if (header_value == 0) {
-            return (TABLE_ERROR);
-        }
-        strcpy(szVal, json_object_get_string(header_value));
-        if (strcmp(header_key, JSON_KEY_HEADER) == 0) {
-            json_object_object_foreach(header_value, header_key, globalAttr) {
-                if (header_key[0] == '#') {
-                    continue;
-                }
-                if (globalAttr == NULL) {
-                    return (TABLE_ERROR);
-                }
-                strcpy(szVal, json_object_get_string(globalAttr));
-                if (cmor_set_dataset_att(&cmor_tables[cmor_ntables], header_key,
-                                        szVal) == 1) {
-                    cmor_pop_traceback();
-                    return (TABLE_ERROR);
+    if (table_type == CMOR_TABLE_VARIABLE) {
+        json_object_object_foreach(json_obj, header_key, header_value) {
+            if (header_key[0] == '#') {
+                continue;
+            }
+            if (header_value == 0) {
+                return (TABLE_ERROR);
+            }
+            strcpy(szVal, json_object_get_string(header_value));
+            if (strcmp(header_key, JSON_KEY_HEADER) == 0) {
+                json_object_object_foreach(header_value, header_key, globalAttr) {
+                    if (header_key[0] == '#') {
+                        continue;
+                    }
+                    if (globalAttr == NULL) {
+                        return (TABLE_ERROR);
+                    }
+                    strcpy(szVal, json_object_get_string(globalAttr));
+                    if (cmor_set_dataset_att(&cmor_tables[cmor_ntables], header_key,
+                                            szVal) == 1) {
+                        cmor_pop_traceback();
+                        return (TABLE_ERROR);
+                    }
                 }
             }
         }
     }
 
+    cv_found = 0;
     json_object_object_foreach(json_obj, key, value) {
 
         if (key[0] == '#') {
@@ -1018,10 +1028,13 @@ int cmor_load_table_internal(char szTable[CMOR_MAX_STRING], int *table_id)
             done = 1;
         } else if (strncmp(key, JSON_KEY_CV_ENTRY, 2) == 0) {
 
+            cmor_validate_cv(value, NULL);
+
             if (cmor_CV_set_entry(&cmor_tables[cmor_ntables], value) == 1) {
                 cmor_pop_traceback();
                 return (TABLE_ERROR);
             }
+            cv_found = 1;
             done = 1;
 
         } else if (strcmp(key, JSON_KEY_MAPPING_ENTRY) == 0) {
@@ -1121,6 +1134,16 @@ int cmor_load_table_internal(char szTable[CMOR_MAX_STRING], int *table_id)
             /*printf("attribute for unknown section\n"); */
         }
     }
+
+    if (table_type == CMOR_TABLE_CV && cv_found == 0) {
+        cmor_handle_error_variadic(
+            "CV section was not found in table: %s",
+            CMOR_CRITICAL,
+            szTable);
+        cmor_pop_traceback();
+        return (TABLE_ERROR);
+    }
+
     *table_id = cmor_ntables;
     CMOR_TABLE = cmor_ntables;
     if (table_file != NULL) {
@@ -1166,4 +1189,154 @@ int cmor_validate_json(json_object *json)
 
     return 0;
 
-}
\ No newline at end of file
+}
+
+
+/************************************************************************/
+/*                         cmor_validate_cv()                           */
+/************************************************************************/
+void cmor_validate_cv(json_object *cv, char *parent_attr)
+{
+    array_list *array;
+    json_object *array_obj;
+    size_t length, i;
+    int single_value_pairs;
+
+    cmor_add_traceback("cmor_validate_cv");
+
+    json_object_object_foreach(cv, attr, value) {
+        single_value_pairs = 0;
+
+        if (parent_attr == NULL) {
+            if (strcmp(attr, CV_KEY_BRANDING_TEMPLATE) == 0) {
+                if (!json_object_is_type(value, json_type_string)) {
+                    cmor_handle_error_variadic(
+                        "Attribute \"%s\" must be a string",
+                        CMOR_WARNING,
+                        attr);
+                        continue;
+                }
+            } else if (strcmp(attr, CV_KEY_MIP_ERA) == 0
+                || strcmp(attr, CV_KEY_DATASPECSVERSION) == 0
+            ) {
+                if (!(json_object_is_type(value, json_type_string)
+                    || json_object_is_type(value, json_type_array))) {
+                    cmor_handle_error_variadic(
+                        "Attribute \"%s\" must be a string or an array",
+                        CMOR_WARNING,
+                        attr);
+                        continue;
+                }
+            } else if (strcmp(attr, CV_KEY_REQUIRED_GBL_ATTRS) == 0
+                || strcmp(attr, GLOBAL_ATT_CONVENTIONS) == 0
+                || strcmp(attr, GLOBAL_ATT_VARIANT_LABEL) == 0
+                || strcmp(attr, GLOBAL_ATT_REALIZATION) == 0
+                || strcmp(attr, GLOBAL_ATT_INITIA_IDX) == 0
+                || strcmp(attr, GLOBAL_ATT_PHYSICS_IDX) == 0
+                || strcmp(attr, GLOBAL_ATT_FORCING_IDX) == 0
+                || strcmp(attr, GLOBAL_ATT_TRACKING_ID) == 0
+            ) {
+                if (!json_object_is_type(value, json_type_array)) {
+                    cmor_handle_error_variadic(
+                        "Attribute \"%s\" must be an array",
+                        CMOR_WARNING,
+                        attr);
+                        continue;
+                }
+            } else if (strcmp(attr, CV_KEY_FREQUENCY) == 0
+                || strcmp(attr, CV_KEY_VERSION_METADATA) == 0
+            ) {
+                if (!json_object_is_type(value, json_type_object)) {
+                    cmor_handle_error_variadic(
+                        "Attribute \"%s\" must be an object",
+                        CMOR_WARNING,
+                        attr);
+                        continue;
+                }
+            } else if (strcmp(attr, CV_KEY_INSTITUTION_ID) == 0
+                || strcmp(attr, CV_KEY_DRS) == 0
+            ) {
+                if (!json_object_is_type(value, json_type_object)) {
+                    cmor_handle_error_variadic(
+                        "Attribute \"%s\" must be an object",
+                        CMOR_WARNING,
+                        attr);
+                        continue;
+                }
+                single_value_pairs = 1;
+            } else if (strcmp(attr, CV_KEY_LICENSE) == 0)
+            {
+                if (!(json_object_is_type(value, json_type_object)
+                     || json_object_is_type(value, json_type_array))) {
+                    cmor_handle_error_variadic(
+                        "Attribute \"%s\" must be an array or object",
+                        CMOR_WARNING,
+                        attr);
+                        continue;
+                }
+            } else if (strcmp(attr, GLOBAL_ATT_SOURCE_TYPE) == 0
+                || strcmp(attr, CV_KEY_GRID_LABELS) == 0
+                || strcmp(attr, CV_KEY_GRID_RESOLUTION) == 0
+                || strcmp(attr, GLOBAL_ATT_REALM) == 0
+            ) {
+                if (!(json_object_is_type(value, json_type_object)
+                     || json_object_is_type(value, json_type_array))) {
+                    cmor_handle_error_variadic(
+                        "Attribute \"%s\" must be an array or object",
+                        CMOR_WARNING,
+                        attr);
+                        continue;
+                }
+                single_value_pairs = 1;
+            } else {
+                if (!(json_object_is_type(value, json_type_object)
+                     || json_object_is_type(value, json_type_array))) {
+                    cmor_handle_error_variadic(
+                        "Attribute \"%s\" must be an array or object",
+                        CMOR_WARNING,
+                        attr);
+                        continue;
+                }
+            }
+        }
+
+        if (json_object_is_type(value, json_type_array)) {
+            array = json_object_get_array(value);
+            length = array_list_length(array);
+            for (i = 0; i < length; i++) {
+                array_obj = (json_object *) array_list_get_idx(array, i);
+                if (!json_object_is_type(array_obj, json_type_string)) {
+                    cmor_handle_error_variadic(
+                        "Attribute \"%s\" has elements in its "
+                        "array that are not strings",
+                        CMOR_WARNING,
+                        attr);
+                        break;
+                }
+            }
+        } else if (json_object_is_type(value, json_type_object)) {
+            json_object_object_foreach(value, k, v) {
+                if (json_object_is_type(v, json_type_array)) {
+                    cmor_handle_error_variadic(
+                        "Value for \"%s\" in attribute \"%s\" "
+                        "cannot be an array",
+                        CMOR_WARNING,
+                        k, attr);
+                } else if (json_object_is_type(v, json_type_object)) {
+                    if (single_value_pairs != 0) {
+                        cmor_handle_error_variadic(
+                            "Value for \"%s\" in attribute \"%s\" "
+                            "cannot be an object",
+                            CMOR_WARNING,
+                            k, attr);
+                    } else if (parent_attr == NULL) {
+                        cmor_validate_cv(v, attr);
+                    }
+                }
+            }
+        }
+    }
+
+    cmor_pop_traceback();
+    return;
+}
