@@ -226,7 +226,7 @@ PROGRAM karls_test
   !   experiment conditions, and provide information to be included as 
   !   attributes in all CF-netCDF files written as part of this dataset.
 
-  error_flag = cmor_dataset_json("common_user_input.json")
+  error_flag = cmor_dataset_json("CMOR_input_example.json")
   
   !  Define all axes that will be needed
 
