@@ -2,7 +2,7 @@
 #define CMOR_H
 
 #define CMOR_VERSION_MAJOR 3
-#define CMOR_VERSION_MINOR 11
+#define CMOR_VERSION_MINOR 12
 #define CMOR_VERSION_PATCH 0
 
 #define CMOR_CF_VERSION_MAJOR 1
@@ -258,6 +258,10 @@
 #define CV_KEY_LICENSE_TEMPLATE       "license_template"
 #define CV_KEY_LICENSE_TYPE           "license_type"
 #define CV_KEY_LICENSE_URL            "license_url"
+#define CV_KEY_VERSION_METADATA       "version_metadata"
+#define CV_KEY_DRS                    "DRS"
+#define CV_KEY_DIR_PATH_TEMPLATE      "directory_path_template"
+#define CV_KEY_FILENAME_TEMPLATE      "filename_template"
 
 #define CV_EXP_ATTR_ADDSOURCETYPE     "additional_allowed_model_components"
 #define CV_EXP_ATTR_REQSOURCETYPE     "required_model_components"
@@ -581,6 +585,12 @@ typedef struct {
     char *value;
 } t_symstruct;
 
+enum cmor_table_type {
+    CMOR_TABLE_VARIABLE,
+    CMOR_TABLE_CV,
+    CMOR_TABLE_FORMULA,
+    CMOR_TABLE_AXIS
+};
 
 typedef struct cmor_table_ {
     int id;
@@ -649,6 +659,8 @@ typedef struct cmor_dataset_def_ {
     int initiated;
     int associate_file;		/*flag to store associated variables separately */
     int associated_file;	/* ncid of associated file */
+    int default_path_template; /* 1 if default path template is in use */
+    int default_file_template; /* 1 if default file name template is in use */
     char associated_file_name[CMOR_MAX_STRING];	/*associated file path */
     char tracking_id[CMOR_MAX_STRING];	/*associated tracking id */
     char path_template[CMOR_MAX_STRING]; /* <keys> for each directory */
